@@ -261,9 +261,11 @@ class AglDSO(cVXI11.IEEE488_2Device):
     def set_wf_point(self,point=b"1000"):
         """
         <# points> ::= {100 | 250 | 500 |1000 | <points_mode>} if waveformpoints mode is NORMal
-        <# points> ::= {100 | 250 | 500 |1000 | 2000 ... 8000000 in 1-2-5sequence | <points_mode>} if waveform points mode is MAXimum or RAW
+        <# points> ::= {100 | 250 | 500 |1000 | 2000 ... 8000000 in 1-2-5sequence | <points_mode>} 
+        if waveform points mode is MAXimum or RAW
         <points_mode> ::= {NORMal |MAXimum | RAW}
-        The raw acquisition record can only be transferred when the oscilloscope is not running and can only be retrieved from the analog or digital sources.
+        The raw acquisition record can only be transferred when the oscilloscope is not running and 
+        can only be retrieved from the analog or digital sources.
         """
         self.write(b":WAV:POIN %s;"%point)
 
@@ -701,3 +703,9 @@ def get_segment(dso,n):
     dso.write(b":WAVEFORM:DATA?;\n")
     r=dso.readResponce()
     return r
+
+def test_dso(host=b"169.254.254.254"):
+    dev=Vxi11Device(host,device=b"inst0")
+    return dev
+
+
